BitReader

Struct BitReader 

pub struct BitReader<T: Read> { /* private fields */ }
A wrapper for any type implementing io::Read that allows the reading of individual bits

Example

use bit_manager::{BitReader, BitRead};

let mut reader = BitReader::new([0b01101110u8, 0b10100000u8].as_ref());

assert_eq!(reader.read_bit()?, false);
assert_eq!(reader.read_bit()?, true);
assert_eq!(reader.read_bit()?, true);
assert_eq!(reader.read_byte()?, 0b01110101);

Implementations

Source

impl<T: Read> BitReader<T>

pub fn new(reader: T) -> BitReader<T>

Creates a new bit reader with the given reader. Uses Precision::Byte by default.

pub fn new_with_precision(reader: T, precision: Precision) -> BitReader<T>

Creates a new bit reader with the given reader and precision.

pub fn is_aligned(&self) -> bool

Returns true if the internal buffer is aligned to a byte.

pub fn align(&mut self) -> Result<()>

Aligns the stream to the next byte.